==> trade-center-api-0.0.2-20160816.072751-35-sources.jar: cn/com/duiba/order/center/api/dto/orders/ObjectAddressDto.java <==
package cn.com.duiba.order.center.api.dto.orders;

import cn.com.duiba.service.domain.dataobject.ConsumerDO;

/**
 * Created by yansen on 16/8/16.
 */
 public class ObjectAddressDto {

    private String addrName;
    private String addrPhone;
    private String addrProvince;
    private String addrCity;
    private String addrArea;
    private String addrDetail;
    public String getAddrName() {
        return addrName;
    }
    public void setAddrName(String addrName) {
        this.addrName = addrName;
    }
    public String getAddrPhone() {
        return addrPhone;
    }
    public void setAddrPhone(String addrPhone) {
        this.addrPhone = addrPhone;
    }
    public String getAddrProvince() {
        return addrProvince;
    }
    public void setAddrProvince(String addrProvince) {
        this.addrProvince = addrProvince;
    }
    public String getAddrCity() {
        return addrCity;
    }
    public void setAddrCity(String addrCity) {
        this.addrCity = addrCity;
    }
    public String getAddrArea() {
        return addrArea;
    }
    public void setAddrArea(String addrArea) {
        this.addrArea = addrArea;
    }
    public String getAddrDetail() {
        return addrDetail;
    }
    public void setAddrDetail(String addrDetail) {
        this.addrDetail = addrDetail;
    }
    public static ObjectAddressDto convertToAddress(ConsumerDO consumer){
        ObjectAddressDto addr=new ObjectAddressDto();
        addr.setAddrArea(consumer.getAddrArea());
        addr.setAddrCity(consumer.getAddrCity());
        addr.setAddrDetail(consumer.getAddrDetail());
        addr.setAddrName(consumer.getAddrName());
        addr.setAddrPhone(consumer.getAddrPhone());
        addr.setAddrProvince(consumer.getAddrProvince());
        return addr;
    }

    public static ObjectAddressDto generateAddress(String addrName, String addrPhone, String addrProvince, String addrCity, String addrArea, String addrDetail){
        ObjectAddressDto addr=new ObjectAddressDto();
        addr.setAddrArea(addrArea);
        addr.setAddrCity(addrCity);
        addr.setAddrDetail(addrDetail);
        addr.setAddrName(addrName);
        addr.setAddrPhone(addrPhone);
        addr.setAddrProvince(addrProvince);
        return addr;
    }



}

==> trade-center-api-0.1.1-20160825.060048-14-sources.jar: cn/com/duiba/order/center/api/dto/orders/ObjectAddressDto.java <==
package cn.com.duiba.order.center.api.dto.orders;

import cn.com.duiba.service.domain.dataobject.ConsumerDO;

import java.io.Serializable;

/**
 * Created by yansen on 16/8/16.
 */
 public class ObjectAddressDto implements Serializable{

    private String addrName;
    private String addrPhone;
    private String addrProvince;
    private String addrCity;
    private String addrArea;
    private String addrDetail;
    public String getAddrName() {
        return addrName;
    }
    public void setAddrName(String addrName) {
        this.addrName = addrName;
    }
    public String getAddrPhone() {
        return addrPhone;
    }
    public void setAddrPhone(String addrPhone) {
        this.addrPhone = addrPhone;
    }
    public String getAddrProvince() {
        return addrProvince;
    }
    public void setAddrProvince(String addrProvince) {
        this.addrProvince = addrProvince;
    }
    public String getAddrCity() {
        return addrCity;
    }
    public void setAddrCity(String addrCity) {
        this.addrCity = addrCity;
    }
    public String getAddrArea() {
        return addrArea;
    }
    public void setAddrArea(String addrArea) {
        this.addrArea = addrArea;
    }
    public String getAddrDetail() {
        return addrDetail;
    }
    public void setAddrDetail(String addrDetail) {
        this.addrDetail = addrDetail;
    }
    public static ObjectAddressDto convertToAddress(ConsumerDO consumer){
        ObjectAddressDto addr=new ObjectAddressDto();
        addr.setAddrArea(consumer.getAddrArea());
        addr.setAddrCity(consumer.getAddrCity());
        addr.setAddrDetail(consumer.getAddrDetail());
        addr.setAddrName(consumer.getAddrName());
        addr.setAddrPhone(consumer.getAddrPhone());
        addr.setAddrProvince(consumer.getAddrProvince());
        return addr;
    }

    public static ObjectAddressDto generateAddress(String addrName, String addrPhone, String addrProvince, String addrCity, String addrArea, String addrDetail){
        ObjectAddressDto addr=new ObjectAddressDto();
        addr.setAddrArea(addrArea);
        addr.setAddrCity(addrCity);
        addr.setAddrDetail(addrDetail);
        addr.setAddrName(addrName);
        addr.setAddrPhone(addrPhone);
        addr.setAddrProvince(addrProvince);
        return addr;
    }



}
